@@ -6,6 +6,7 @@ from pydantic import UUID4, BaseModel, IPvAnyAddress, IPvAnyNetwork, validator
 from typing import Optional
 from enum import Enum
 from os import environ 
+from uuid import uuid4
 
 # client = httpx.Client(
 #     base_url=environ.get("CVE_SEARCH_API", "https://cve.circ.lu/api"),
@@ -30,9 +31,9 @@ class Timeline(BaseModel):
 
 class Campaign(BaseModel):
     name: str 
-    identifier: UUID4
     timeline: Timeline 
     scopes: list[Scope] = []
+    identifier: UUID4 = uuid4()
 
 
 # class ResourceType(Enum):
